@@ -80,19 +80,22 @@ class TeleBot:
         getChatMembersCount
         getChatMember
         answerCallbackQuery
+        setMyCommands
         answerInlineQuery
         """
 
     def __init__(
-            self, token, threaded=True, skip_pending=False, num_threads=2,
+            self, token, parse_mode=None, threaded=True, skip_pending=False, num_threads=2,
             next_step_backend=None, reply_backend=None
     ):
         """
         :param token: bot API token
+        :param parse_mode: default parse_mode
         :return: Telebot object.
         """
 
         self.token = token
+        self.parse_mode = parse_mode
         self.update_listener = []
         self.skip_pending = skip_pending
 
@@ -118,6 +121,7 @@ class TeleBot:
         self.shipping_query_handlers = []
         self.pre_checkout_query_handlers = []
         self.poll_handlers = []
+        self.poll_answer_handlers = []
 
         self.typed_middleware_handlers = {
             'message': [],
@@ -292,6 +296,7 @@ class TeleBot:
         new_shipping_querys = []
         new_pre_checkout_querys = []
         new_polls = []
+        new_poll_answers = []
 
         for update in updates:
             if apihelper.ENABLE_MIDDLEWARE:
@@ -319,6 +324,8 @@ class TeleBot:
                 new_pre_checkout_querys.append(update.pre_checkout_query)
             if update.poll:
                 new_polls.append(update.poll)
+            if update.poll_answer:
+                new_poll_answers.append(update.poll_answer)
 
         logger.debug('Received {0} new updates'.format(len(updates)))
         if len(new_messages) > 0:
@@ -341,6 +348,8 @@ class TeleBot:
             self.process_new_pre_checkout_query(new_pre_checkout_querys)
         if len(new_polls) > 0:
             self.process_new_poll(new_polls)
+        if len(new_poll_answers) > 0:
+            self.process_new_poll_answer(new_poll_answers)
 
     def process_new_messages(self, new_messages):
         self._notify_next_handlers(new_messages)
@@ -375,6 +384,9 @@ class TeleBot:
     def process_new_poll(self, polls):
         self._notify_command_handlers(self.poll_handlers, polls)
 
+    def process_new_poll_answer(self, poll_answers):
+        self._notify_command_handlers(self.poll_answer_handlers, poll_answers)
+
     def process_middlewares(self, update):
         for update_type, middlewares in self.typed_middleware_handlers.items():
             if getattr(update, update_type) is not None:
@@ -546,9 +558,11 @@ class TeleBot:
 
     def get_chat_administrators(self, chat_id):
         """
-        Use this method to get a list of administrators in a chat. On success, returns an Array of ChatMember objects
-        that contains information about all chat administrators except other bots.
-        :param chat_id:
+        Use this method to get a list of administrators in a chat.
+        On success, returns an Array of ChatMember objects that contains
+            information about all chat administrators except other bots.
+        :param chat_id: Unique identifier for the target chat or username
+            of the target supergroup or channel (in the format @channelusername)
         :return:
         """
         result = apihelper.get_chat_administrators(self.token, chat_id)
@@ -620,11 +634,13 @@ class TeleBot:
         :param timeout:
         :return: API reply.
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+
         return types.Message.de_json(
             apihelper.send_message(self.token, chat_id, text, disable_web_page_preview, reply_to_message_id,
                                    reply_markup, parse_mode, disable_notification, timeout))
 
-    def forward_message(self, chat_id, from_chat_id, message_id, disable_notification=None):
+    def forward_message(self, chat_id, from_chat_id, message_id, disable_notification=None, timeout=None):
         """
         Use this method to forward messages of any kind.
         :param disable_notification:
@@ -634,7 +650,7 @@ class TeleBot:
         :return: API reply.
         """
         return types.Message.de_json(
-            apihelper.forward_message(self.token, chat_id, from_chat_id, message_id, disable_notification))
+            apihelper.forward_message(self.token, chat_id, from_chat_id, message_id, disable_notification, timeout))
 
     def delete_message(self, chat_id, message_id):
         """
@@ -645,7 +661,10 @@ class TeleBot:
         """
         return apihelper.delete_message(self.token, chat_id, message_id)
 
-    def send_dice(self, chat_id, emoji=None, disable_notification=None, reply_to_message_id=None, reply_markup=None):
+    def send_dice(
+            self, chat_id,
+            emoji=None, disable_notification=None, reply_to_message_id=None,
+            reply_markup=None, timeout=None):
         """
         Use this method to send dices.
         :param chat_id:
@@ -656,11 +675,13 @@ class TeleBot:
         :return: Message
         """
         return types.Message.de_json(
-            apihelper.send_dice(self.token, chat_id, emoji, disable_notification, reply_to_message_id, reply_markup)
+            apihelper.send_dice(
+                self.token, chat_id, emoji, disable_notification, reply_to_message_id,
+                reply_markup, timeout)
         )
 
     def send_photo(self, chat_id, photo, caption=None, reply_to_message_id=None, reply_markup=None,
-                   parse_mode=None, disable_notification=None):
+                   parse_mode=None, disable_notification=None, timeout=None):
         """
         Use this method to send photos.
         :param disable_notification:
@@ -672,13 +693,15 @@ class TeleBot:
         :param reply_markup:
         :return: API reply.
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+
         return types.Message.de_json(
             apihelper.send_photo(self.token, chat_id, photo, caption, reply_to_message_id, reply_markup,
-                                 parse_mode, disable_notification))
+                                 parse_mode, disable_notification, timeout))
 
     def send_audio(self, chat_id, audio, caption=None, duration=None, performer=None, title=None,
                    reply_to_message_id=None, reply_markup=None, parse_mode=None, disable_notification=None,
-                   timeout=None):
+                   timeout=None, thumb=None):
         """
         Use this method to send audio files, if you want Telegram clients to display them in the music player. Your audio must be in the .mp3 format.
         :param chat_id:Unique identifier for the message recipient
@@ -692,11 +715,12 @@ class TeleBot:
         :param parse_mode
         :param disable_notification:
         :param timeout:
+	:param thumb:
         :return: Message
         """
         return types.Message.de_json(
             apihelper.send_audio(self.token, chat_id, audio, caption, duration, performer, title, reply_to_message_id,
-                                 reply_markup, parse_mode, disable_notification, timeout))
+                                 reply_markup, parse_mode, disable_notification, timeout, thumb))
 
     def send_voice(self, chat_id, voice, caption=None, duration=None, reply_to_message_id=None, reply_markup=None,
                    parse_mode=None, disable_notification=None, timeout=None):
@@ -713,6 +737,8 @@ class TeleBot:
         :param timeout:
         :return: Message
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+
         return types.Message.de_json(
             apihelper.send_voice(self.token, chat_id, voice, caption, duration, reply_to_message_id, reply_markup,
                                  parse_mode, disable_notification, timeout))
@@ -731,12 +757,15 @@ class TeleBot:
         :param timeout:
         :return: API reply.
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+
         return types.Message.de_json(
             apihelper.send_data(self.token, chat_id, data, 'document', reply_to_message_id, reply_markup,
                                 parse_mode, disable_notification, timeout, caption=caption))
 
-    def send_sticker(self, chat_id, data, reply_to_message_id=None, reply_markup=None, disable_notification=None,
-                     timeout=None):
+    def send_sticker(
+            self, chat_id, data, reply_to_message_id=None, reply_markup=None,
+            disable_notification=None, timeout=None):
         """
         Use this method to send .webp stickers.
         :param chat_id:
@@ -748,11 +777,12 @@ class TeleBot:
         :return: API reply.
         """
         return types.Message.de_json(
-            apihelper.send_data(self.token, chat_id, data, 'sticker', reply_to_message_id, reply_markup,
-                                disable_notification, timeout))
+            apihelper.send_data(
+                self.token, chat_id, data, 'sticker', reply_to_message_id, reply_markup,
+                disable_notification, timeout))
 
     def send_video(self, chat_id, data, duration=None, caption=None, reply_to_message_id=None, reply_markup=None,
-                   parse_mode=None, supports_streaming=None, disable_notification=None, timeout=None):
+                   parse_mode=None, supports_streaming=None, disable_notification=None, timeout=None, thumb=None):
         """
         Use this method to send video files, Telegram clients support mp4 videos.
         :param chat_id: Integer : Unique identifier for the message recipient — User or GroupChat id
@@ -765,11 +795,14 @@ class TeleBot:
         :param reply_markup:
         :param disable_notification:
         :param timeout:
+	    :param thumb:
         :return:
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+
         return types.Message.de_json(
             apihelper.send_video(self.token, chat_id, data, duration, caption, reply_to_message_id, reply_markup,
-                                 parse_mode, supports_streaming, disable_notification, timeout))
+                                 parse_mode, supports_streaming, disable_notification, timeout, thumb))
 
     def send_animation(self, chat_id, animation, duration=None, caption=None, reply_to_message_id=None, reply_markup=None,
                    parse_mode=None, disable_notification=None, timeout=None):
@@ -786,6 +819,8 @@ class TeleBot:
         :param timeout:
         :return:
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+
         return types.Message.de_json(
             apihelper.send_animation(self.token, chat_id, animation, duration, caption, reply_to_message_id, reply_markup,
                                  parse_mode, disable_notification, timeout))
@@ -808,7 +843,9 @@ class TeleBot:
             apihelper.send_video_note(self.token, chat_id, data, duration, length, reply_to_message_id, reply_markup,
                                       disable_notification, timeout))
 
-    def send_media_group(self, chat_id, media, disable_notification=None, reply_to_message_id=None):
+    def send_media_group(
+            self, chat_id, media,
+            disable_notification=None, reply_to_message_id=None, timeout=None):
         """
         send a group of photos or videos as an album. On success, an array of the sent Messages is returned.
         :param chat_id:
@@ -817,14 +854,16 @@ class TeleBot:
         :param reply_to_message_id:
         :return:
         """
-        result = apihelper.send_media_group(self.token, chat_id, media, disable_notification, reply_to_message_id)
+        result = apihelper.send_media_group(
+            self.token, chat_id, media, disable_notification, reply_to_message_id, timeout)
         ret = []
         for msg in result:
             ret.append(types.Message.de_json(msg))
         return ret
 
-    def send_location(self, chat_id, latitude, longitude, live_period=None, reply_to_message_id=None, reply_markup=None,
-                      disable_notification=None):
+    def send_location(
+            self, chat_id, latitude, longitude, live_period=None, reply_to_message_id=None,
+            reply_markup=None, disable_notification=None, timeout=None):
         """
         Use this method to send point on the map.
         :param chat_id:
@@ -837,12 +876,12 @@ class TeleBot:
         :return: API reply.
         """
         return types.Message.de_json(
-            apihelper.send_location(self.token, chat_id, latitude, longitude, live_period, reply_to_message_id,
-                                    reply_markup,
-                                    disable_notification))
+            apihelper.send_location(
+                self.token, chat_id, latitude, longitude, live_period, reply_to_message_id,
+                reply_markup, disable_notification, timeout))
 
     def edit_message_live_location(self, latitude, longitude, chat_id=None, message_id=None,
-                                   inline_message_id=None, reply_markup=None):
+                                   inline_message_id=None, reply_markup=None, timeout=None):
         """
         Use this method to edit live location
         :param latitude:
@@ -854,10 +893,13 @@ class TeleBot:
         :return:
         """
         return types.Message.de_json(
-            apihelper.edit_message_live_location(self.token, latitude, longitude, chat_id, message_id,
-                                                 inline_message_id, reply_markup))
+            apihelper.edit_message_live_location(
+                self.token, latitude, longitude, chat_id, message_id,
+                inline_message_id, reply_markup, timeout))
 
-    def stop_message_live_location(self, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
+    def stop_message_live_location(
+            self, chat_id=None, message_id=None,
+            inline_message_id=None, reply_markup=None, timeout=None):
         """
         Use this method to stop updating a live location message sent by the bot
         or via the bot (for inline bots) before live_period expires
@@ -868,10 +910,12 @@ class TeleBot:
         :return:
         """
         return types.Message.de_json(
-            apihelper.stop_message_live_location(self.token, chat_id, message_id, inline_message_id, reply_markup))
+            apihelper.stop_message_live_location(
+                self.token, chat_id, message_id, inline_message_id, reply_markup, timeout))
 
-    def send_venue(self, chat_id, latitude, longitude, title, address, foursquare_id=None, disable_notification=None,
-                   reply_to_message_id=None, reply_markup=None):
+    def send_venue(
+            self, chat_id, latitude, longitude, title, address, foursquare_id=None, disable_notification=None,
+            reply_to_message_id=None, reply_markup=None, timeout=None):
         """
         Use this method to send information about a venue.
         :param chat_id: Integer or String : Unique identifier for the target chat or username of the target channel
@@ -886,18 +930,22 @@ class TeleBot:
         :return:
         """
         return types.Message.de_json(
-            apihelper.send_venue(self.token, chat_id, latitude, longitude, title, address, foursquare_id,
-                                 disable_notification, reply_to_message_id, reply_markup)
+            apihelper.send_venue(
+                self.token, chat_id, latitude, longitude, title, address, foursquare_id,
+                disable_notification, reply_to_message_id, reply_markup, timeout)
         )
 
-    def send_contact(self, chat_id, phone_number, first_name, last_name=None, disable_notification=None,
-                     reply_to_message_id=None, reply_markup=None):
+    def send_contact(
+            self, chat_id, phone_number, first_name,
+            last_name=None, disable_notification=None,
+            reply_to_message_id=None, reply_markup=None, timeout=None):
         return types.Message.de_json(
-            apihelper.send_contact(self.token, chat_id, phone_number, first_name, last_name, disable_notification,
-                                   reply_to_message_id, reply_markup)
+            apihelper.send_contact(
+                self.token, chat_id, phone_number, first_name, last_name, disable_notification,
+                reply_to_message_id, reply_markup, timeout)
         )
 
-    def send_chat_action(self, chat_id, action):
+    def send_chat_action(self, chat_id, action, timeout=None):
         """
         Use this method when you need to tell the user that something is happening on the bot's side.
         The status is set for 5 seconds or less (when a message arrives from your bot, Telegram clients clear
@@ -907,7 +955,7 @@ class TeleBot:
                         'record_audio', 'upload_audio', 'upload_document', 'find_location', 'record_video_note', 'upload_video_note'.
         :return: API reply. :type: boolean
         """
-        return apihelper.send_chat_action(self.token, chat_id, action)
+        return apihelper.send_chat_action(self.token, chat_id, action, timeout)
 
     def kick_chat_member(self, chat_id, user_id, until_date=None):
         """
@@ -929,9 +977,12 @@ class TeleBot:
         """
         return apihelper.unban_chat_member(self.token, chat_id, user_id)
 
-    def restrict_chat_member(self, chat_id, user_id, until_date=None, can_send_messages=None,
-                             can_send_media_messages=None, can_send_other_messages=None,
-                             can_add_web_page_previews=None, can_invite_users=None):
+    def restrict_chat_member(
+            self, chat_id, user_id, until_date=None,
+            can_send_messages=None, can_send_media_messages=None,
+            can_send_polls=None, can_send_other_messages=None,
+            can_add_web_page_previews=None, can_change_info=None,
+            can_invite_users=None, can_pin_messages=None):
         """
         Use this method to restrict a user in a supergroup.
         The bot must be an administrator in the supergroup for this to work and must have
@@ -946,17 +997,23 @@ class TeleBot:
         :param can_send_messages: Pass True, if the user can send text messages, contacts, locations and venues
         :param can_send_media_messages Pass True, if the user can send audios, documents, photos, videos, video notes
             and voice notes, implies can_send_messages
+        :param can_send_polls: Pass True, if the user is allowed to send polls, implies can_send_messages
         :param can_send_other_messages: Pass True, if the user can send animations, games, stickers and
             use inline bots, implies can_send_media_messages
         :param can_add_web_page_previews: Pass True, if the user may add web page previews to their messages,
             implies can_send_media_messages
-	:param can_invite_users: Pass True, if the user is allowed to invite new users to the chat,
-	    implies can_invite_users
+        :param can_change_info: Pass True, if the user is allowed to change the chat title, photo and other settings. Ignored in public supergroups
+    	:param can_invite_users: Pass True, if the user is allowed to invite new users to the chat,
+	        implies can_invite_users
+        :param can_pin_messages: Pass True, if the user is allowed to pin messages. Ignored in public supergroups
         :return: types.Message
         """
-        return apihelper.restrict_chat_member(self.token, chat_id, user_id, until_date, can_send_messages,
-                                              can_send_media_messages, can_send_other_messages,
-                                              can_add_web_page_previews, can_invite_users)
+        return apihelper.restrict_chat_member(
+            self.token, chat_id, user_id, until_date,
+            can_send_messages, can_send_media_messages,
+            can_send_polls, can_send_other_messages,
+            can_add_web_page_previews, can_change_info,
+            can_invite_users, can_pin_messages)
 
     def promote_chat_member(self, chat_id, user_id, can_change_info=None, can_post_messages=None,
                             can_edit_messages=None, can_delete_messages=None, can_invite_users=None,
@@ -984,6 +1041,33 @@ class TeleBot:
                                              can_edit_messages, can_delete_messages, can_invite_users,
                                              can_restrict_members, can_pin_messages, can_promote_members)
 
+    def set_chat_administrator_custom_title(self, chat_id, user_id, custom_title):
+        """
+        Use this method to set a custom title for an administrator
+            in a supergroup promoted by the bot.
+        Returns True on success.
+        :param chat_id: Unique identifier for the target chat or username of the target supergroup
+            (in the format @supergroupusername)
+        :param user_id: Unique identifier of the target user
+        :param custom_title: New custom title for the administrator;
+            0-16 characters, emoji are not allowed
+        :return:
+        """
+        return apihelper.set_chat_administrator_custom_title(self.token, chat_id, user_id, custom_title)
+
+
+    def set_chat_permissions(self, chat_id, permissions):
+        """
+        Use this method to set default chat permissions for all members.
+            The bot must be an administrator in the group or a supergroup for this to work
+            and must have the can_restrict_members admin rights.
+        :param chat_id: Unique identifier for the target chat or username of the target supergroup
+            (in the format @supergroupusername)
+        :param permissions: New default chat permissions
+        :return:
+        """
+        return apihelper.set_chat_permissions(self.token, chat_id, permissions)
+
     def export_chat_invite_link(self, chat_id):
         """
         Use this method to export an invite link to a supergroup or a channel. The bot must be an administrator
@@ -1022,6 +1106,15 @@ class TeleBot:
         """
         return apihelper.delete_chat_photo(self.token, chat_id)
 
+    def set_my_commands(self, commands):
+        """
+        Use this method to change the list of the bot's commands.
+        :param commands: Array of BotCommand. A JSON-serialized list of bot commands
+            to be set as the list of the bot's commands. At most 100 commands can be specified.
+        :return:
+        """
+        return apihelper.set_my_commands(self.token, commands)
+
     def set_chat_title(self, chat_id, title):
         """
         Use this method to change the title of a chat. Titles can't be changed for private chats.
@@ -1086,6 +1179,8 @@ class TeleBot:
         :param reply_markup:
         :return:
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+
         result = apihelper.edit_message_text(self.token, text, chat_id, message_id, inline_message_id, parse_mode,
                                              disable_web_page_preview, reply_markup)
         if type(result) == bool:  # if edit inline message return is bool not Message.
@@ -1121,8 +1216,9 @@ class TeleBot:
             return result
         return types.Message.de_json(result)
 
-    def send_game(self, chat_id, game_short_name, disable_notification=None, reply_to_message_id=None,
-                  reply_markup=None):
+    def send_game(
+            self, chat_id, game_short_name, disable_notification=None,
+            reply_to_message_id=None, reply_markup=None, timeout=None):
         """
         Used to send the game
         :param chat_id:
@@ -1132,8 +1228,9 @@ class TeleBot:
         :param reply_markup:
         :return:
         """
-        result = apihelper.send_game(self.token, chat_id, game_short_name, disable_notification, reply_to_message_id,
-                                     reply_markup)
+        result = apihelper.send_game(
+            self.token, chat_id, game_short_name, disable_notification,
+            reply_to_message_id, reply_markup, timeout)
         return types.Message.de_json(result)
 
     def set_game_score(self, user_id, score, force=None, chat_id=None, message_id=None, inline_message_id=None,
@@ -1174,7 +1271,7 @@ class TeleBot:
                      start_parameter, photo_url=None, photo_size=None, photo_width=None, photo_height=None,
                      need_name=None, need_phone_number=None, need_email=None, need_shipping_address=None,
                      is_flexible=None, disable_notification=None, reply_to_message_id=None, reply_markup=None,
-                     provider_data=None):
+                     provider_data=None, timeout=None):
         """
         Sends invoice
 	    :param chat_id:
@@ -1200,24 +1297,49 @@ class TeleBot:
         :param provider_data:
         :return:
         """
-        result = apihelper.send_invoice(self.token, chat_id, title, description, invoice_payload, provider_token,
-                                        currency, prices, start_parameter, photo_url, photo_size, photo_width,
-                                        photo_height,
-                                        need_name, need_phone_number, need_email, need_shipping_address, is_flexible,
-                                        disable_notification, reply_to_message_id, reply_markup, provider_data)
+        result = apihelper.send_invoice(
+            self.token, chat_id, title, description, invoice_payload, provider_token,
+            currency, prices, start_parameter, photo_url, photo_size, photo_width,
+            photo_height, need_name, need_phone_number, need_email, need_shipping_address,
+            is_flexible, disable_notification, reply_to_message_id, reply_markup,
+            provider_data, timeout)
         return types.Message.de_json(result)
 
-    def send_poll(self, chat_id, poll, explanation_parse_mode=None, disable_notifications=False, reply_to_message=None, reply_markup=None):
+    def send_poll(
+            self, chat_id, question, options,
+            is_anonymous=None, type=None, allows_multiple_answers=None, correct_option_id=None,
+            explanation=None, explanation_parse_mode=None, open_period=None, close_date=None, is_closed=None,
+            disable_notifications=False, reply_to_message_id=None, reply_markup=None, timeout=None):
         """
-        Sends poll
+        Send polls
         :param chat_id:
-        :param poll:
+        :param question:
+        :param options: array of str with answers
+        :param is_anonymous:
+        :param type:
+        :param allows_multiple_answers:
+        :param correct_option_id:
+        :param explanation:
+        :param explanation_parse_mode:
+        :param open_period:
+        :param close_date:
+        :param is_closed:
         :param disable_notifications:
-        :param reply_to_message:
+        :param reply_to_message_id:
         :param reply_markup:
         :return:
         """
-        return types.Message.de_json(apihelper.send_poll(self.token, chat_id, poll, explanation_parse_mode, disable_notifications, reply_to_message, reply_markup))
+
+        if isinstance(question, types.Poll):
+            raise Exception("The send_poll signature was changed, please see send_poll function details.")
+
+        return types.Message.de_json(
+            apihelper.send_poll(
+                self.token, chat_id,
+                question, options,
+                is_anonymous, type, allows_multiple_answers, correct_option_id,
+                explanation, explanation_parse_mode, open_period, close_date, is_closed,
+                disable_notifications, reply_to_message_id, reply_markup, timeout))
 
     def stop_poll(self, chat_id, message_id):
         """
@@ -1261,6 +1383,8 @@ class TeleBot:
         :param reply_markup:
         :return:
         """
+        parse_mode = self.parse_mode if not parse_mode else parse_mode
+        
         result = apihelper.edit_message_caption(self.token, caption, chat_id, message_id, inline_message_id,
                                                 parse_mode, reply_markup)
         if type(result) == bool:
@@ -1497,7 +1621,7 @@ class TeleBot:
         """
         return {
             'function': handler,
-            'filters' : filters
+            'filters': filters
         }
 
     def middleware_handler(self, update_types=None):
@@ -1836,6 +1960,28 @@ class TeleBot:
         """
         self.poll_handlers.append(handler_dict)
 
+    def poll_answer_handler(self, func=None, **kwargs):
+        """
+        Poll_answer request handler
+        :param func:
+        :param kwargs:
+        :return:
+        """
+        def decorator(handler):
+            handler_dict = self._build_handler_dict(handler, func=func, **kwargs)
+            self.add_poll_answer_handler(handler_dict)
+            return handler
+
+        return decorator
+
+    def add_poll_answer_handler(self, handler_dict):
+        """
+        Adds a poll_answer request handler
+        :param handler_dict:
+        :return:
+        """
+        self.poll_answer_handlers.append(handler_dict)
+
     def _test_message_handler(self, message_handler, message):
         """
         Test message handler
