@@ -20,6 +20,7 @@ from telebot import util
 logger = telebot.logger
 
 proxy = None
+session = None
 
 API_URL = None
 FILE_URL = None
@@ -33,7 +34,7 @@ ENABLE_MIDDLEWARE = False
 
 
 def _get_req_session(reset=False):
-    return util.per_thread('req_session', lambda: requests.session(), reset)
+    return util.per_thread('req_session', lambda: session if session else requests.session(), reset)
 
 
 def _make_request(token, method_name, method='get', params=None, files=None):
@@ -57,10 +58,13 @@ def _make_request(token, method_name, method='get', params=None, files=None):
     if files and format_header_param:
         fields.format_header_param = _no_encode(format_header_param)
     if params:
-        if 'timeout' in params: read_timeout = params['timeout'] + 10
-        if 'connect-timeout' in params: connect_timeout = params['connect-timeout'] + 10
-    result = _get_req_session().request(method, request_url, params=params, files=files,
-                                        timeout=(connect_timeout, read_timeout), proxies=proxy)
+        if 'timeout' in params:
+            read_timeout = params.pop('timeout') + 10
+        if 'connect-timeout' in params:
+            connect_timeout = params.pop('connect-timeout') + 10
+    result = _get_req_session().request(
+        method, request_url, params=params, files=files,
+        timeout=(connect_timeout, read_timeout), proxies=proxy)
     logger.debug("The server returned: '{0}'".format(result.text.encode('utf8')))
     return _check_result(method_name, result)['result']
 
@@ -128,8 +132,10 @@ def download_file(token, file_path):
     return result.content
 
 
-def send_message(token, chat_id, text, disable_web_page_preview=None, reply_to_message_id=None, reply_markup=None,
-                 parse_mode=None, disable_notification=None, timeout=None):
+def send_message(
+        token, chat_id, text,
+        disable_web_page_preview=None, reply_to_message_id=None, reply_markup=None,
+        parse_mode=None, disable_notification=None, timeout=None):
     """
     Use this method to send text messages. On success, the sent Message is returned.
     :param token:
@@ -140,11 +146,12 @@ def send_message(token, chat_id, text, disable_web_page_preview=None, reply_to_m
     :param reply_markup:
     :param parse_mode:
     :param disable_notification:
+    :param timeout:
     :return:
     """
     method_url = r'sendMessage'
     payload = {'chat_id': str(chat_id), 'text': text}
-    if disable_web_page_preview:
+    if disable_web_page_preview is not None:
         payload['disable_web_page_preview'] = disable_web_page_preview
     if reply_to_message_id:
         payload['reply_to_message_id'] = reply_to_message_id
@@ -152,7 +159,7 @@ def send_message(token, chat_id, text, disable_web_page_preview=None, reply_to_m
         payload['reply_markup'] = _convert_markup(reply_markup)
     if parse_mode:
         payload['parse_mode'] = parse_mode
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if timeout:
         payload['connect-timeout'] = timeout
@@ -251,30 +258,41 @@ def get_chat_member(token, chat_id, user_id):
     return _make_request(token, method_url, params=payload)
 
 
-def forward_message(token, chat_id, from_chat_id, message_id, disable_notification=None):
+def forward_message(
+        token, chat_id, from_chat_id, message_id,
+        disable_notification=None, timeout=None):
     method_url = r'forwardMessage'
     payload = {'chat_id': chat_id, 'from_chat_id': from_chat_id, 'message_id': message_id}
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
-def send_dice(token, chat_id, emoji=None, disable_notification=None, reply_to_message_id=None, reply_markup=None):
+def send_dice(
+        token, chat_id,
+        emoji=None, disable_notification=None, reply_to_message_id=None,
+        reply_markup=None, timeout=None):
     method_url = r'sendDice'
     payload = {'chat_id': chat_id}
     if emoji:
         payload['emoji'] = emoji
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if reply_to_message_id:
         payload['reply_to_message_id'] = reply_to_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
-def send_photo(token, chat_id, photo, caption=None, reply_to_message_id=None, reply_markup=None,
-               parse_mode=None, disable_notification=None):
+def send_photo(
+        token, chat_id, photo,
+        caption=None, reply_to_message_id=None, reply_markup=None,
+        parse_mode=None, disable_notification=None, timeout=None):
     method_url = r'sendPhoto'
     payload = {'chat_id': chat_id}
     files = None
@@ -290,25 +308,36 @@ def send_photo(token, chat_id, photo, caption=None, reply_to_message_id=None, re
         payload['reply_markup'] = _convert_markup(reply_markup)
     if parse_mode:
         payload['parse_mode'] = parse_mode
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload, files=files, method='post')
 
 
-def send_media_group(token, chat_id, media, disable_notification=None, reply_to_message_id=None):
+def send_media_group(
+        token, chat_id, media,
+        disable_notification=None, reply_to_message_id=None,
+        timeout=None):
     method_url = r'sendMediaGroup'
     media_json, files = _convert_input_media_array(media)
     payload = {'chat_id': chat_id, 'media': media_json}
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if reply_to_message_id:
         payload['reply_to_message_id'] = reply_to_message_id
-    return _make_request(token, method_url, params=payload, method='post' if files else 'get',
-                         files=files if files else None)
+    if timeout:
+        payload['connect-timeout'] = timeout
+    return _make_request(
+        token, method_url, params=payload,
+        method='post' if files else 'get',
+        files=files if files else None)
 
 
-def send_location(token, chat_id, latitude, longitude, live_period=None, reply_to_message_id=None, reply_markup=None,
-                  disable_notification=None):
+def send_location(
+        token, chat_id, latitude, longitude,
+        live_period=None, reply_to_message_id=None, reply_markup=None,
+        disable_notification=None, timeout=None):
     method_url = r'sendLocation'
     payload = {'chat_id': chat_id, 'latitude': latitude, 'longitude': longitude}
     if live_period:
@@ -317,13 +346,15 @@ def send_location(token, chat_id, latitude, longitude, live_period=None, reply_t
         payload['reply_to_message_id'] = reply_to_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
 def edit_message_live_location(token, latitude, longitude, chat_id=None, message_id=None,
-                               inline_message_id=None, reply_markup=None):
+                               inline_message_id=None, reply_markup=None, timeout=None):
     method_url = r'editMessageLiveLocation'
     payload = {'latitude': latitude, 'longitude': longitude}
     if chat_id:
@@ -334,11 +365,14 @@ def edit_message_live_location(token, latitude, longitude, chat_id=None, message
         payload['inline_message_id'] = inline_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
-def stop_message_live_location(token, chat_id=None, message_id=None,
-                               inline_message_id=None, reply_markup=None):
+def stop_message_live_location(
+        token, chat_id=None, message_id=None,
+        inline_message_id=None, reply_markup=None, timeout=None):
     method_url = r'stopMessageLiveLocation'
     payload = {}
     if chat_id:
@@ -349,47 +383,59 @@ def stop_message_live_location(token, chat_id=None, message_id=None,
         payload['inline_message_id'] = inline_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
-def send_venue(token, chat_id, latitude, longitude, title, address, foursquare_id=None, disable_notification=None,
-               reply_to_message_id=None, reply_markup=None):
+def send_venue(
+        token, chat_id, latitude, longitude, title, address,
+        foursquare_id=None, disable_notification=None,
+        reply_to_message_id=None, reply_markup=None, timeout=None):
     method_url = r'sendVenue'
     payload = {'chat_id': chat_id, 'latitude': latitude, 'longitude': longitude, 'title': title, 'address': address}
     if foursquare_id:
         payload['foursquare_id'] = foursquare_id
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if reply_to_message_id:
         payload['reply_to_message_id'] = reply_to_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
-def send_contact(token, chat_id, phone_number, first_name, last_name=None, disable_notification=None,
-                 reply_to_message_id=None, reply_markup=None):
+def send_contact(
+        token, chat_id, phone_number, first_name,
+        last_name=None, disable_notification=None,
+        reply_to_message_id=None, reply_markup=None, timeout=None):
     method_url = r'sendContact'
     payload = {'chat_id': chat_id, 'phone_number': phone_number, 'first_name': first_name}
     if last_name:
         payload['last_name'] = last_name
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if reply_to_message_id:
         payload['reply_to_message_id'] = reply_to_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
-def send_chat_action(token, chat_id, action):
+def send_chat_action(token, chat_id, action, timeout=None):
     method_url = r'sendChatAction'
     payload = {'chat_id': chat_id, 'action': action}
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
 def send_video(token, chat_id, data, duration=None, caption=None, reply_to_message_id=None, reply_markup=None,
-               parse_mode=None, supports_streaming=None, disable_notification=None, timeout=None):
+               parse_mode=None, supports_streaming=None, disable_notification=None, timeout=None, thumb=None):
     method_url = r'sendVideo'
     payload = {'chat_id': chat_id}
     files = None
@@ -407,12 +453,17 @@ def send_video(token, chat_id, data, duration=None, caption=None, reply_to_messa
         payload['reply_markup'] = _convert_markup(reply_markup)
     if parse_mode:
         payload['parse_mode'] = parse_mode
-    if supports_streaming:
+    if supports_streaming is not None:
         payload['supports_streaming'] = supports_streaming
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if timeout:
         payload['connect-timeout'] = timeout
+    if thumb:
+        if not util.is_string(thumb):
+            files['thumb'] = thumb
+        else:
+            payload['thumb'] = thumb
     return _make_request(token, method_url, params=payload, files=files, method='post')
 
 
@@ -435,7 +486,7 @@ def send_animation(token, chat_id, data, duration=None, caption=None, reply_to_m
         payload['reply_markup'] = _convert_markup(reply_markup)
     if parse_mode:
         payload['parse_mode'] = parse_mode
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if timeout:
         payload['connect-timeout'] = timeout
@@ -461,7 +512,7 @@ def send_voice(token, chat_id, voice, caption=None, duration=None, reply_to_mess
         payload['reply_markup'] = _convert_markup(reply_markup)
     if parse_mode:
         payload['parse_mode'] = parse_mode
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if timeout:
         payload['connect-timeout'] = timeout
@@ -487,7 +538,7 @@ def send_video_note(token, chat_id, data, duration=None, length=None, reply_to_m
         payload['reply_to_message_id'] = reply_to_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if timeout:
         payload['connect-timeout'] = timeout
@@ -495,7 +546,7 @@ def send_video_note(token, chat_id, data, duration=None, length=None, reply_to_m
 
 
 def send_audio(token, chat_id, audio, caption=None, duration=None, performer=None, title=None, reply_to_message_id=None,
-               reply_markup=None, parse_mode=None, disable_notification=None, timeout=None):
+               reply_markup=None, parse_mode=None, disable_notification=None, timeout=None, thumb=None):
     method_url = r'sendAudio'
     payload = {'chat_id': chat_id}
     files = None
@@ -517,10 +568,15 @@ def send_audio(token, chat_id, audio, caption=None, duration=None, performer=Non
         payload['reply_markup'] = _convert_markup(reply_markup)
     if parse_mode:
         payload['parse_mode'] = parse_mode
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if timeout:
         payload['connect-timeout'] = timeout
+    if thumb:
+        if not util.is_string(thumb):
+            files['thumb'] = thumb
+        else:
+            payload['thumb'] = thumb
     return _make_request(token, method_url, params=payload, files=files, method='post')
 
 
@@ -539,7 +595,7 @@ def send_data(token, chat_id, data, data_type, reply_to_message_id=None, reply_m
         payload['reply_markup'] = _convert_markup(reply_markup)
     if parse_mode and data_type == 'document':
         payload['parse_mode'] = parse_mode
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if timeout:
         payload['connect-timeout'] = timeout
@@ -569,51 +625,77 @@ def unban_chat_member(token, chat_id, user_id):
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def restrict_chat_member(token, chat_id, user_id, until_date=None, can_send_messages=None,
-                         can_send_media_messages=None, can_send_other_messages=None,
-                         can_add_web_page_previews=None, can_invite_users=None):
+def restrict_chat_member(
+        token, chat_id, user_id, until_date=None,
+        can_send_messages=None, can_send_media_messages=None,
+        can_send_polls=None, can_send_other_messages=None,
+        can_add_web_page_previews=None, can_change_info=None,
+        can_invite_users=None, can_pin_messages=None):
     method_url = 'restrictChatMember'
     payload = {'chat_id': chat_id, 'user_id': user_id}
-    if until_date:
+    if until_date is not None:
         payload['until_date'] = until_date
-    if can_send_messages:
+    if can_send_messages is not None:
         payload['can_send_messages'] = can_send_messages
-    if can_send_media_messages:
+    if can_send_media_messages is not None:
         payload['can_send_media_messages'] = can_send_media_messages
-    if can_send_other_messages:
+    if can_send_polls is not None:
+        payload['can_send_polls'] = can_send_polls
+    if can_send_other_messages is not None:
         payload['can_send_other_messages'] = can_send_other_messages
-    if can_add_web_page_previews:
+    if can_add_web_page_previews is not None:
         payload['can_add_web_page_previews'] = can_add_web_page_previews
-    if can_invite_users:
+    if can_change_info is not None:
+        payload['can_change_info'] = can_change_info
+    if can_invite_users is not None:
         payload['can_invite_users'] = can_invite_users
-        
+    if can_pin_messages is not None:
+        payload['can_pin_messages'] = can_pin_messages
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def promote_chat_member(token, chat_id, user_id, can_change_info=None, can_post_messages=None,
-                        can_edit_messages=None, can_delete_messages=None, can_invite_users=None,
-                        can_restrict_members=None, can_pin_messages=None, can_promote_members=None):
+def promote_chat_member(
+        token, chat_id, user_id, can_change_info=None, can_post_messages=None,
+        can_edit_messages=None, can_delete_messages=None, can_invite_users=None,
+        can_restrict_members=None, can_pin_messages=None, can_promote_members=None):
     method_url = 'promoteChatMember'
     payload = {'chat_id': chat_id, 'user_id': user_id}
-    if can_change_info:
+    if can_change_info is not None:
         payload['can_change_info'] = can_change_info
-    if can_post_messages:
+    if can_post_messages is not None:
         payload['can_post_messages'] = can_post_messages
-    if can_edit_messages:
+    if can_edit_messages is not None:
         payload['can_edit_messages'] = can_edit_messages
-    if can_delete_messages:
+    if can_delete_messages is not None:
         payload['can_delete_messages'] = can_delete_messages
-    if can_invite_users:
+    if can_invite_users is not None:
         payload['can_invite_users'] = can_invite_users
-    if can_restrict_members:
+    if can_restrict_members is not None:
         payload['can_restrict_members'] = can_restrict_members
-    if can_pin_messages:
+    if can_pin_messages is not None:
         payload['can_pin_messages'] = can_pin_messages
-    if can_promote_members:
+    if can_promote_members is not None:
         payload['can_promote_members'] = can_promote_members
     return _make_request(token, method_url, params=payload, method='post')
 
 
+def set_chat_administrator_custom_title(token, chat_id, user_id, custom_title):
+    method_url = 'setChatAdministratorCustomTitle'
+    payload = {
+        'chat_id': chat_id, 'user_id': user_id, 'custom_title': custom_title
+    }
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def set_chat_permissions(token, chat_id, permissions):
+    method_url = 'setChatPermissions'
+    payload = {
+        'chat_id': chat_id,
+        'permissions': permissions.to_json()
+    }
+    return _make_request(token, method_url, params=payload, method='post')
+
+
 def export_chat_invite_link(token, chat_id):
     method_url = 'exportChatInviteLink'
     payload = {'chat_id': chat_id}
@@ -643,15 +725,23 @@ def set_chat_title(token, chat_id, title):
     return _make_request(token, method_url, params=payload, method='post')
 
 
+def set_my_commands(token, commands):
+    method_url = r'setMyCommands'
+    payload = {'commands': _convert_list_json_serializable(commands)}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
 def set_chat_description(token, chat_id, description):
     method_url = 'setChatDescription'
     payload = {'chat_id': chat_id, 'description': description}
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def pin_chat_message(token, chat_id, message_id, disable_notification=False):
+def pin_chat_message(token, chat_id, message_id, disable_notification=None):
     method_url = 'pinChatMessage'
-    payload = {'chat_id': chat_id, 'message_id': message_id, 'disable_notification': disable_notification}
+    payload = {'chat_id': chat_id, 'message_id': message_id}
+    if disable_notification is not None:
+        payload['disable_notification'] = disable_notification
     return _make_request(token, method_url, params=payload, method='post')
 
 
@@ -675,7 +765,7 @@ def edit_message_text(token, text, chat_id=None, message_id=None, inline_message
         payload['inline_message_id'] = inline_message_id
     if parse_mode:
         payload['parse_mode'] = parse_mode
-    if disable_web_page_preview:
+    if disable_web_page_preview is not None:
         payload['disable_web_page_preview'] = disable_web_page_preview
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
@@ -736,15 +826,19 @@ def delete_message(token, chat_id, message_id):
 
 # Game
 
-def send_game(token, chat_id, game_short_name, disable_notification=None, reply_to_message_id=None, reply_markup=None):
+def send_game(
+        token, chat_id, game_short_name,
+        disable_notification=None, reply_to_message_id=None, reply_markup=None, timeout=None):
     method_url = r'sendGame'
     payload = {'chat_id': chat_id, 'game_short_name': game_short_name}
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if reply_to_message_id:
         payload['reply_to_message_id'] = reply_to_message_id
     if reply_markup:
         payload['reply_markup'] = _convert_markup(reply_markup)
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
@@ -765,7 +859,7 @@ def set_game_score(token, user_id, score, force=None, disable_edit_message=None,
     """
     method_url = r'setGameScore'
     payload = {'user_id': user_id, 'score': score}
-    if force:
+    if force is not None:
         payload['force'] = force
     if chat_id:
         payload['chat_id'] = chat_id
@@ -773,7 +867,7 @@ def set_game_score(token, user_id, score, force=None, disable_edit_message=None,
         payload['message_id'] = message_id
     if inline_message_id:
         payload['inline_message_id'] = inline_message_id
-    if disable_edit_message:
+    if disable_edit_message is not None:
         payload['disable_edit_message'] = disable_edit_message
     return _make_request(token, method_url, params=payload)
 
@@ -803,10 +897,12 @@ def get_game_high_scores(token, user_id, chat_id=None, message_id=None, inline_m
 
 # Payments (https://core.telegram.org/bots/api#payments)
 
-def send_invoice(token, chat_id, title, description, invoice_payload, provider_token, currency, prices,
-                 start_parameter, photo_url=None, photo_size=None, photo_width=None, photo_height=None,
-                 need_name=None, need_phone_number=None, need_email=None, need_shipping_address=None, is_flexible=None,
-                 disable_notification=None, reply_to_message_id=None, reply_markup=None, provider_data=None):
+def send_invoice(
+        token, chat_id, title, description, invoice_payload, provider_token, currency, prices,
+        start_parameter, photo_url=None, photo_size=None, photo_width=None, photo_height=None,
+        need_name=None, need_phone_number=None, need_email=None, need_shipping_address=None, is_flexible=None,
+        disable_notification=None, reply_to_message_id=None, reply_markup=None, provider_data=None,
+        timeout=None):
     """
     Use this method to send invoices. On success, the sent Message is returned.
     :param token: Bot's token (you don't need to fill this)
@@ -845,17 +941,17 @@ def send_invoice(token, chat_id, title, description, invoice_payload, provider_t
         payload['photo_width'] = photo_width
     if photo_height:
         payload['photo_height'] = photo_height
-    if need_name:
+    if need_name is not None:
         payload['need_name'] = need_name
-    if need_phone_number:
+    if need_phone_number is not None:
         payload['need_phone_number'] = need_phone_number
-    if need_email:
+    if need_email is not None:
         payload['need_email'] = need_email
-    if need_shipping_address:
+    if need_shipping_address is not None:
         payload['need_shipping_address'] = need_shipping_address
-    if is_flexible:
+    if is_flexible is not None:
         payload['is_flexible'] = is_flexible
-    if disable_notification:
+    if disable_notification is not None:
         payload['disable_notification'] = disable_notification
     if reply_to_message_id:
         payload['reply_to_message_id'] = reply_to_message_id
@@ -863,6 +959,8 @@ def send_invoice(token, chat_id, title, description, invoice_payload, provider_t
         payload['reply_markup'] = _convert_markup(reply_markup)
     if provider_data:
         payload['provider_data'] = provider_data
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
@@ -920,7 +1018,7 @@ def answer_callback_query(token, callback_query_id, text=None, show_alert=None,
     payload = {'callback_query_id': callback_query_id}
     if text:
         payload['text'] = text
-    if show_alert:
+    if show_alert is not None:
         payload['show_alert'] = show_alert
     if url:
         payload['url'] = url
@@ -935,7 +1033,7 @@ def answer_inline_query(token, inline_query_id, results, cache_time=None, is_per
     payload = {'inline_query_id': inline_query_id, 'results': _convert_list_json_serializable(results)}
     if cache_time is not None:
         payload['cache_time'] = cache_time
-    if is_personal:
+    if is_personal is not None:
         payload['is_personal'] = is_personal
     if next_offset is not None:
         payload['next_offset'] = next_offset
@@ -958,7 +1056,9 @@ def upload_sticker_file(token, user_id, png_sticker):
     return _make_request(token, method_url, params=payload, files=files, method='post')
 
 
-def create_new_sticker_set(token, user_id, name, title, png_sticker, emojis, contains_masks=None, mask_position=None):
+def create_new_sticker_set(
+        token, user_id, name, title, png_sticker, emojis,
+        contains_masks=None, mask_position=None):
     method_url = 'createNewStickerSet'
     payload = {'user_id': user_id, 'name': name, 'title': title, 'emojis': emojis}
     files = None
@@ -966,7 +1066,7 @@ def create_new_sticker_set(token, user_id, name, title, png_sticker, emojis, con
         files = {'png_sticker': png_sticker}
     else:
         payload['png_sticker'] = png_sticker
-    if contains_masks:
+    if contains_masks is not None:
         payload['contains_masks'] = contains_masks
     if mask_position:
         payload['mask_position'] = mask_position.to_json()
@@ -998,31 +1098,36 @@ def delete_sticker_from_set(token, sticker):
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def send_poll(token, chat_id, poll, explanation_parse_mode=None, disable_notifications=False, reply_to_message_id=None, reply_markup=None):
+def send_poll(
+        token, chat_id,
+        question, options,
+        is_anonymous = None, type = None, allows_multiple_answers = None, correct_option_id = None,
+        explanation = None, explanation_parse_mode=None, open_period = None, close_date = None, is_closed = None,
+        disable_notifications=False, reply_to_message_id=None, reply_markup=None, timeout=None):
     method_url = r'sendPoll'
     payload = {
         'chat_id': str(chat_id),
-        'question': poll.question,
-        'options': _convert_list_json_serializable(poll.options)}
+        'question': question,
+        'options': json.dumps(options)}
 
-    if poll.is_anonymous is not None:
-        payload['is_anonymous'] = poll.is_anonymous
-    if poll.type is not None:
-        payload['type'] = poll.type
-    if poll.allows_multiple_answers is not None:
-        payload['allows_multiple_answers'] = poll.allows_multiple_answers
-    if poll.correct_option_id is not None:
-        payload['correct_option_id'] = poll.correct_option_id
-    if poll.explanation is not None:
-        payload['explanation'] = poll.explanation
+    if is_anonymous is not None:
+        payload['is_anonymous'] = is_anonymous
+    if type is not None:
+        payload['type'] = type
+    if allows_multiple_answers is not None:
+        payload['allows_multiple_answers'] = allows_multiple_answers
+    if correct_option_id is not None:
+        payload['correct_option_id'] = correct_option_id
+    if explanation is not None:
+        payload['explanation'] = explanation
     if explanation_parse_mode is not None:
         payload['explanation_parse_mode'] = explanation_parse_mode
-    if poll.open_period is not None:
-        payload['open_period'] = poll.open_period
-    if poll.close_date is not None:
-        payload['close_date'] = poll.close_date
-    if poll.is_closed is not None:
-        payload['is_closed'] = poll.is_closed
+    if open_period is not None:
+        payload['open_period'] = open_period
+    if close_date is not None:
+        payload['close_date'] = close_date
+    if is_closed is not None:
+        payload['is_closed'] = is_closed
 
     if disable_notifications:
         payload['disable_notification'] = disable_notifications
@@ -1030,6 +1135,8 @@ def send_poll(token, chat_id, poll, explanation_parse_mode=None, disable_notific
         payload['reply_to_message_id'] = reply_to_message_id
     if reply_markup is not None:
         payload['reply_markup'] = _convert_markup(reply_markup)
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
@@ -1068,7 +1175,7 @@ def _convert_input_media_array(array):
     files = {}
     for input_media in array:
         if isinstance(input_media, types.InputMedia):
-            media_dict = input_media.to_dic()
+            media_dict = input_media.to_dict()
             if media_dict['media'].startswith('attach://'):
                 key = media_dict['media'].replace('attach://', '')
                 files[key] = input_media.media
